<?php

namespace Drupal\paid_ads\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\Annotation\FieldFormatter;
use Drupal\Core\Annotation\Translation;

/**
 * Plugin implementation of the 'paid' formatter.
 *
 * @FieldFormatter(
 *   id = "paid_boolean",
 *   label = @Translation("Paid(boolean)"),
 *   field_types = {
 *     "paid_boolean",
 *   }
 * )
 */
class PaidFormatter extends FormatterBase {

  /**
   * PaidService injection.
   *
   * @var \Drupal\paid_ads\PaidService
   */
  private $paidService;

  /**
   * {@inheritdoc}
   */
  public function __construct(string $plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, string $label, string $view_mode, array $third_party_settings) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->paidService = \Drupal::getContainer()->get('paid.service');
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    $settings = parent::defaultSettings();
    $settings['paid_display'] = 'Paid';
    $settings['not_paid_display'] = '';

    return $settings;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);

    $form['not_paid_display'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Label for non paid payment'),
      '#default_value' => $this->getSetting('not_paid_display'),
    ];

    $form['paid_display'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Label for non paid payment'),
      '#default_value' => $this->getSetting('paid_display'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {

    if (!$items->first()->value) {
      $pluginId = $items->getSetting('type');
      $form['label'] = [
        '#markup' => $this->getSetting('not_paid_display'),
      ];
      $form['plugin'] = $this->paidService->buildFormByPluginId($pluginId, [
        'amount' => $items->getSetting('amount'),
      ]);
      $id = implode('_', [
        $items->getFieldDefinition()->getTargetEntityTypeId(),
        $items->getFieldDefinition()->getTargetBundle(),
        $items->getFieldDefinition()->getName(),
        $items->getEntity()->id(),
        1,
      ]);
      $form['plugin']['#attributes'] = array_merge($form['plugin']['#attributes'] ?? [],
        [
          'data-entity-type' => $items->getFieldDefinition()
            ->getTargetEntityTypeId(),
          'data-bundle' => $items->getFieldDefinition()->getTargetBundle(),
          'data-field' => $items->getFieldDefinition()->getName(),
          'data-entity-id' => $items->getEntity()->id(),
          'data-field-value' => 1,
          'id' => $id,
        ]);
      return [$form];
    }
    else {
      return [
        [
          '#markup' => $this->getSetting('paid_display'),
        ],
      ];
    }
  }

}
