<?php

namespace Drupal\paid_ads\Plugin;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\PluginBase;

/**
 * Base class for Paid gateways plugins.
 */
abstract class PaidGatewaysPluginBase extends PluginBase implements PaidGatewayInterface {


  /**
   * ConfigFactory injection.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configurationStorage;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, string $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configurationStorage = \Drupal::configFactory()
      ->getEditable('paid.payments');
  }

  /**
   * {@inheritdoc}
   */
  abstract public function getForm(array $option);

  /**
   * {@inheritdoc}
   */
  public function getConfigForm(array $form, FormStateInterface $form_state) {
    return [
      'form' => $this->buildConfigurationForm($form, $form_state),
      '#tree' => TRUE,
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Save'),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function setOptions(array $options = []) {
    $this->configurationStorage->set($this->getPluginId() . '.config', $options)
      ->save();
  }

  /**
   * {@inheritdoc}
   */
  public function getOptions() {
    return $this->configurationStorage->get($this->pluginId . '.config') ?? [];
  }

  /**
   * {@inheritdoc}
   */
  abstract public function onCreatePayment(array $context);

  /**
   * {@inheritdoc}
   */
  abstract public function onExecutePayment(array $context);

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
  }

}
